@@ -21,7 +21,7 @@ use clap::{load_yaml, App};
 
 use codec::Compact;
 use sp_keyring::AccountKeyring;
-use sp_core::crypto::Pair;
+use sp_runtime::generic::Era;
 use substrate_api_client::{
     compose_call, compose_extrinsic_offline, Api, GenericAddress, UncheckedExtrinsicV4, XtStatus,
 };
@@ -46,24 +46,23 @@ fn main() {
     let first_nonce = nonce;
     while nonce < first_nonce + 500 {
         #[allow(clippy::redundant_clone)]
-        let call = compose_call!(
-            api.metadata.clone(),
+        let call = compose_call(
+            &api.metadata,
             "Balances",
             "transfer",
-            GenericAddress::Id(to.clone()),
-            Compact(10_u128.pow(9))
+            (GenericAddress::Id(to.clone()), Compact(10_u128.pow(9))),
         );
         // compose the extrinsic with all the element
         #[allow(clippy::redundant_clone)]
-        let xt: UncheckedExtrinsicV4<_> = compose_extrinsic_offline!(
-            api.clone().signer.unwrap(),
+        let xt: UncheckedExtrinsicV4<_> = compose_extrinsic_offline(
+            api.signer.as_ref().unwrap(),
             call,
             nonce,
             Era::Immortal,
             api.genesis_hash,
             api.genesis_hash,
             api.runtime_version.spec_version,
-            api.runtime_version.transaction_version
+            api.runtime_version.transaction_version,
         );
         // send and watch extrinsic until finalized
         println!("sending extrinsic with nonce {}", nonce);
