@@ -47,7 +47,6 @@ use utils::*;
 #[cfg(feature = "std")]
 use sp_version::RuntimeVersion;
 
-#[macro_use]
 pub mod extrinsic;
 #[cfg(feature = "std")]
 pub mod events;
@@ -71,11 +70,12 @@ pub mod rpc;
 #[cfg(feature = "std")]
 use events::{EventsDecoder, RawEvent, RuntimeEvent};
 #[cfg(feature = "std")]
-use sp_runtime::{generic::SignedBlock, AccountId32 as AccountId, MultiSignature};
+use sp_runtime::{generic::SignedBlock, MultiSignature};
 
 pub extern crate sp_runtime;
 
 pub use sp_core::H256 as Hash;
+pub use sp_runtime::AccountId32 as AccountId;
 
 /// The block number type used in this runtime.
 pub type BlockNumber = u64;
@@ -86,6 +86,7 @@ pub type Moment = u64;
 pub type Index = u32;
 
 // re-export useful types
+pub use extrinsic::*;
 pub use extrinsic::xt_primitives::{GenericAddress, GenericExtra, UncheckedExtrinsicV4};
 #[cfg(feature = "std")]
 pub use node_metadata::Metadata;
@@ -620,7 +621,7 @@ pub enum ApiClientError {
     #[error("Events Error: {0}")]
     Events(#[from] crate::events::EventsError),
     #[error("Error decoding storage value: {0}")]
-    StorageValueDecode(#[from] extrinsic::codec::Error),
+    StorageValueDecode(#[from] codec::Error),
     #[error("Received invalid hex string: {0}")]
     InvalidHexString(#[from] hex::FromHexError),
     #[error("Error deserializing with serde: {0}")]
