@@ -14,9 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with substrate-subxt.  If not, see <http://www.gnu.org/licenses/>.
 
-use std::{collections::HashMap, convert::TryFrom, marker::PhantomData, str::FromStr};
-
-use codec::Encode;
+use std::{collections::HashMap, convert::TryFrom, str::FromStr};
 
 use frame_metadata::{
     DecodeDifferent, EventMetadata, RuntimeMetadata, RuntimeMetadataPrefixed, StorageEntryMetadata,
@@ -159,16 +157,16 @@ impl Metadata {
             .key())
     }
 
-    pub fn storage_map_key<K: Encode>(
+    pub fn storage_map_key(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        map_key: K,
+        map_key: Vec<u8>,
     ) -> Result<StorageKey, MetadataError> {
         Ok(self
             .module(storage_prefix)?
             .storage(storage_key_name)?
-            .get_map::<K>()?
+            .get_map()?
             .key(map_key))
     }
 
@@ -182,17 +180,17 @@ impl Metadata {
             .get_map_prefix()
     }
 
-    pub fn storage_double_map_key<K: Encode, Q: Encode>(
+    pub fn storage_double_map_key(
         &self,
         storage_prefix: &str,
         storage_key_name: &str,
-        first: K,
-        second: Q,
+        first: Vec<u8>,
+        second: Vec<u8>,
     ) -> Result<StorageKey, MetadataError> {
         Ok(self
             .module(storage_prefix)?
             .storage(storage_key_name)?
-            .get_double_map::<K, Q>()?
+            .get_double_map()?
             .key(first, second))
     }
 }
@@ -279,9 +277,9 @@ pub struct StorageMetadata {
 }
 
 impl StorageMetadata {
-    pub fn get_double_map<K: Encode, Q: Encode>(
+    pub fn get_double_map(
         &self,
-    ) -> Result<StorageDoubleMap<K, Q>, MetadataError> {
+    ) -> Result<StorageDoubleMap, MetadataError> {
         match &self.ty {
             StorageEntryType::DoubleMap {
                 hasher,
@@ -298,8 +296,6 @@ impl StorageMetadata {
                     self.module_prefix, self.storage_prefix, hasher1, hasher2
                 );
                 Ok(StorageDoubleMap {
-                    _marker: PhantomData,
-                    _marker2: PhantomData,
                     module_prefix,
                     storage_prefix,
                     hasher: hasher1,
@@ -309,7 +305,7 @@ impl StorageMetadata {
             _ => Err(MetadataError::StorageTypeError),
         }
     }
-    pub fn get_map<K: Encode>(&self) -> Result<StorageMap<K>, MetadataError> {
+    pub fn get_map(&self) -> Result<StorageMap, MetadataError> {
         match &self.ty {
             StorageEntryType::Map { hasher, .. } => {
                 let module_prefix = self.module_prefix.as_bytes().to_vec();
@@ -321,7 +317,6 @@ impl StorageMetadata {
                     self.module_prefix, self.storage_prefix, hasher
                 );
                 Ok(StorageMap {
-                    _marker: PhantomData,
                     module_prefix,
                     storage_prefix,
                     hasher,
@@ -371,38 +366,35 @@ impl StorageValue {
 }
 
 #[derive(Clone, Debug)]
-pub struct StorageMap<K> {
-    _marker: PhantomData<K>,
+pub struct StorageMap {
     module_prefix: Vec<u8>,
     storage_prefix: Vec<u8>,
     hasher: StorageHasher,
 }
 
-impl<K: Encode> StorageMap<K> {
-    pub fn key(&self, key: K) -> StorageKey {
+impl StorageMap {
+    pub fn key(&self, key: Vec<u8>) -> StorageKey {
         let mut bytes = sp_core::twox_128(&self.module_prefix).to_vec();
         bytes.extend(&sp_core::twox_128(&self.storage_prefix)[..]);
-        bytes.extend(key_hash(&key, &self.hasher));
+        bytes.extend(key_hash(key, &self.hasher));
         StorageKey(bytes)
     }
 }
 
 #[derive(Clone, Debug)]
-pub struct StorageDoubleMap<K, Q> {
-    _marker: PhantomData<K>,
-    _marker2: PhantomData<Q>,
+pub struct StorageDoubleMap {
     module_prefix: Vec<u8>,
     storage_prefix: Vec<u8>,
     hasher: StorageHasher,
     key2_hasher: StorageHasher,
 }
 
-impl<K: Encode, Q: Encode> StorageDoubleMap<K, Q> {
-    pub fn key(&self, key1: K, key2: Q) -> StorageKey {
+impl StorageDoubleMap {
+    pub fn key(&self, key1: Vec<u8>, key2: Vec<u8>) -> StorageKey {
         let mut bytes = sp_core::twox_128(&self.module_prefix).to_vec();
         bytes.extend(&sp_core::twox_128(&self.storage_prefix)[..]);
-        bytes.extend(key_hash(&key1, &self.hasher));
-        bytes.extend(key_hash(&key2, &self.key2_hasher));
+        bytes.extend(key_hash(key1, &self.hasher));
+        bytes.extend(key_hash(key2, &self.key2_hasher));
         StorageKey(bytes)
     }
 }
@@ -601,8 +593,7 @@ fn convert_entry(
 }
 
 /// generates the key's hash depending on the StorageHasher selected
-fn key_hash<K: Encode>(key: &K, hasher: &StorageHasher) -> Vec<u8> {
-    let encoded_key = key.encode();
+fn key_hash(encoded_key: Vec<u8>, hasher: &StorageHasher) -> Vec<u8> {
     match hasher {
         StorageHasher::Identity => encoded_key.to_vec(),
         StorageHasher::Blake2_128 => sp_core::blake2_128(&encoded_key).to_vec(),
